* FROM: http://www.ats.ucla.edu/stat/sas/dae/ologit.htm;

* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=MAX formdlim=' ' spool; 									
* Kill default titles on output, ODS tables in log, turn on graphics; 
TITLE; ODS TRACE OFF; ODS LISTING; ODS HTML CLOSE; ODS GRAPHICS ON;

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR EXAMPLE 10b              *******
*******             CHANGE "filesave" to your directory                  *******
********************************************************************************

* Location for original files for these models  change this path;
%LET filesave= C:\Dropbox\14_SPLH861\861_Example10; 
LIBNAME filesave "&filesave.";

* Send data to STATA;
PROC EXPORT DATA=filesave.ologit OUTFILE="&filesave.\ologit.dta" DBMS=STATA REPLACE; RUN;

* Creating formats for categorical variables;
PROC FORMAT; 
    VALUE F3apply 0="0No" 1="1Maybe" 2="2Yes";
RUN;
* Import data into work library, transform variables, apply value formats;
DATA work.ologit; SET filesave.ologit;
    parentGD=pared;
    GPA3=GPA-3;
         IF public=1 THEN private=0; 
    ELSE IF public=0 THEN private=1;
    ELSE IF public=. THEN private=.;
    LABEL apply=    "apply: 0=No, 1=Maybe, 2=Yes"
          parentGD= "parentGD: Parent Has Graduate Degree (0=N,1=Y)"
          private=  "private: Student Attends Private University (0=N,1=Y)"
          GPA3=     "GPA3: Student GPA (0=3)";  
	FORMAT apply F3apply.;
RUN;

********************************************************************************
******                    BEGIN EXAMPLE 10b MODELS						 *******
********************************************************************************

* Open output directory to save results to;
ODS RTF FILE="&filesave.\SAS_Example10b_Output.rtf" STYLE=HTMLBlue STARTPAGE=NO;

TITLE1 "DESCRIPTIVES FOR STUDY VARIABLES";
PROC MEANS DATA=work.ologit; 
     VAR GPA; 
RUN;
PROC FREQ DATA=work.ologit;
     TABLE apply parentGD private; 
RUN; TITLE1;

TITLE1 "EMPTY ORDINAL MODEL PREDICTING CATEGORICAL DV";
PROC GLIMMIX DATA=work.ologit NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
MODEL apply (DESCENDING) = / SOLUTION LINK=CLOGIT DIST=MULT;
* ILINK requests logit estimate to be transformed into probability, but does not give each;
ESTIMATE "Intercept" intercept 1 / ILINK;
RUN; TITLE1; 

TITLE1 "MAIN EFFECTS ORDINAL MODEL PREDICTING CATEGORICAL DV";
PROC GLIMMIX DATA=work.ologit NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
MODEL apply (DESCENDING) = GPA3 parentGD private / SOLUTION LINK=CLOGIT DIST=MULT;
ESTIMATE "Int for No  Degree, Public,  GPA=2" int 1 GPA3 -1 parentGD 0 private 0 / ILINK;
ESTIMATE "Int for No  Degree, Private, GPA=2" int 1 GPA3 -1 parentGD 0 private 1 / ILINK;
ESTIMATE "Int for Yes Degree, Public,  GPA=2" int 1 GPA3 -1 parentGD 1 private 0 / ILINK;
ESTIMATE "Int for Yes Degree, Private, GPA=2" int 1 GPA3 -1 parentGD 1 private 1 / ILINK;
ESTIMATE "Int for No  Degree, Public,  GPA=3" int 1 GPA3  0 parentGD 0 private 0 / ILINK;
ESTIMATE "Int for No  Degree, Private, GPA=3" int 1 GPA3  0 parentGD 0 private 1 / ILINK;
ESTIMATE "Int for Yes Degree, Public,  GPA=3" int 1 GPA3  0 parentGD 1 private 0 / ILINK;
ESTIMATE "Int for Yes Degree, Private, GPA=3" int 1 GPA3  0 parentGD 1 private 1 / ILINK;
ESTIMATE "Int for No  Degree, Public,  GPA=4" int 1 GPA3  1 parentGD 0 private 0 / ILINK;
ESTIMATE "Int for No  Degree, Private, GPA=4" int 1 GPA3  1 parentGD 0 private 1 / ILINK;
ESTIMATE "Int for Yes Degree, Public,  GPA=4" int 1 GPA3  1 parentGD 1 private 0 / ILINK;
ESTIMATE "Int for Yes Degree, Private, GPA=4" int 1 GPA3  1 parentGD 1 private 1 / ILINK;
ESTIMATE "Slope for GPA" GPA3 1 / ILINK; * Example of non-sense ILINK for a slope; 
RUN; TITLE1; 

TITLE1 "EMPTY NOMINAL MODEL PREDICTING CATEGORICAL DV";
PROC GLIMMIX DATA=work.ologit NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
MODEL apply (REFERENCE="1Maybe") = / SOLUTION LINK=GLOGIT DIST=MULT;
* ILINK requests logit estimate to be transformed into probability;
ESTIMATE "Intercept" intercept 1 / ILINK BYCAT; * BYCAT gives per submodel;
RUN; TITLE1; 

TITLE1 "MAIN EFFECTS NOMINAL MODEL PREDICTING CATEGORICAL DV";
PROC GLIMMIX DATA=work.ologit NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
MODEL apply (REFERENCE="1Maybe") = GPA3 parentGD private / SOLUTION LINK=GLOGIT DIST=MULT;
ESTIMATE "Int for No  Degree, Public,  GPA=2" int 1 GPA3 -1 parentGD 0 private 0 / ILINK BYCAT;
ESTIMATE "Int for No  Degree, Private, GPA=2" int 1 GPA3 -1 parentGD 0 private 1 / ILINK BYCAT;
ESTIMATE "Int for Yes Degree, Public,  GPA=2" int 1 GPA3 -1 parentGD 1 private 0 / ILINK BYCAT;
ESTIMATE "Int for Yes Degree, Private, GPA=2" int 1 GPA3 -1 parentGD 1 private 1 / ILINK BYCAT;
ESTIMATE "Int for No  Degree, Public,  GPA=3" int 1 GPA3  0 parentGD 0 private 0 / ILINK BYCAT;
ESTIMATE "Int for No  Degree, Private, GPA=3" int 1 GPA3  0 parentGD 0 private 1 / ILINK BYCAT;
ESTIMATE "Int for Yes Degree, Public,  GPA=3" int 1 GPA3  0 parentGD 1 private 0 / ILINK BYCAT;
ESTIMATE "Int for Yes Degree, Private, GPA=3" int 1 GPA3  0 parentGD 1 private 1 / ILINK BYCAT;
ESTIMATE "Int for No  Degree, Public,  GPA=4" int 1 GPA3  1 parentGD 0 private 0 / ILINK BYCAT;
ESTIMATE "Int for No  Degree, Private, GPA=4" int 1 GPA3  1 parentGD 0 private 1 / ILINK BYCAT;
ESTIMATE "Int for Yes Degree, Public,  GPA=4" int 1 GPA3  1 parentGD 1 private 0 / ILINK BYCAT;
ESTIMATE "Int for Yes Degree, Private, GPA=4" int 1 GPA3  1 parentGD 1 private 1 / ILINK BYCAT;
RUN; TITLE1; 

***** TRICKING A NOMINAL MODEL OUT OF A MULTIVARIATE MODEL;
***** provides a way to directly test differences between the sub-model slopes;

* Stack data into multivariate to get tests of proportional odds;
DATA work.ologitstacked; SET work.ologit;
IF apply=0 THEN DO; MaybevsNo=1; MaybevsYes=.; END;
IF apply=1 THEN DO; MaybevsNo=0; MaybevsYes=0; END;
IF apply=2 THEN DO; MaybevsNo=.; MaybevsYes=1; END;
DV10=1; DV12=0; y=MaybevsNo;  OUTPUT;
DV10=0; DV12=1; y=MaybevsYes; OUTPUT;
LABEL DV10= "DV10: Is testing Maybe vs. No  (0=N,1=Y)"
      DV12= "DV12: Is testing Maybe vs. Yes (0=N,1=Y)"
	  y=	"y: Actual response";
RUN;

TITLE1 "EMPTY MULTIVARIATE MODEL PREDICTING DUMMY-CODED DVs";
PROC GLIMMIX DATA=work.ologitstacked NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
MODEL y (DESCENDING) = DV10 DV12 / NOINT SOLUTION LINK=LOGIT DIST=BINARY;
ESTIMATE "Intercept for DV10" DV10 1 / ILINK;
ESTIMATE "Intercept for DV12" DV12 1 / ILINK;
RUN; TITLE1; 

TITLE1 "MAIN EFFECTS MULTIVARIATE MODEL PREDICTING DUMMY-CODED DVs";
TITLE2 "TO GET DIRECT TESTS OF PROPORTIONAL ODDS";
PROC GLIMMIX DATA=work.ologitstacked NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
MODEL y (DESCENDING) = DV10 DV12 DV10*GPA3 DV12*GPA3 DV10*parentGD DV12*parentGD DV10*private DV12*private 
						/ NOINT SOLUTION LINK=LOGIT DIST=BINARY;
* Note that estimates below flip the sign of the DV10 effects (to test diffs in absolute value);	
ESTIMATE "Difference in GPA Slope across Submodels"      	DV10*GPA3     1  DV12*GPA3     1; 
ESTIMATE "Difference in ParentGD Slope across Submodels" 	DV10*parentGD 1  DV12*parentGD 1; 
ESTIMATE "Difference in Private Slope across Submodels"  	DV10*private  1  DV12*private  1; 
RUN; TITLE1; 

* Close output;
ODS RTF CLOSE; 


