* Prevent "more" messages from appearing
set more off, permanently
* Control line length
set linesize 150

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR EXAMPLE 10               *******
*******             CHANGE "filesave" to your directory                  *******
********************************************************************************

* Defining global variable for file location to be replaced in code below
global filesave "C:\Dropbox\14_SPLH861\861_Example10"
 
* Import data, transform variables, apply value formats
use "$filesave\ologit.dta", clear
gen parentgd=pared
gen gpa3=gpa-3
gen private=0
recode private (0=1) if public==0
label variable apply    "apply: 0=No, 1=Maybe, 2=Yes"
label variable parentgd "parentgd: Parent Has Graduate Degree (0=N,1=Y)"
label variable private  "private: Student Attends Private University (0=N,1=Y)"
label variable gpa3     "gpa3: Student GPA (0=3)"
label define f3apply     0 "0No" 1 "1Maybe" 2 "2Yes"
label values apply f3apply

 
********************************************************************************
******                    BEGIN EXAMPLE 10b MODELS						                 *******
********************************************************************************

* Save results to separate file
log using $filesave\STATA_Example10b_Output.log, replace name(STATA_Example10b)
 
display as result "DESCRIPTIVES FOR STUDY VARIABLES"
summarize gpa
tabulate apply
tabulate parentgd
tabulate private

display as result "EMPTY ORDINAL MODEL PREDICTING CATEGORICAL DV"
display as result "INTERCEPTS ARE BACKWARDS (GIVES LOGIT OF LOWER CATEGORY)" 
meologit apply ,  
estat ic, n(400),
nlcom 1/(1+exp(-1*(_b[cut1:_cons]))) // intercept for y<1 in probability
nlcom 1/(1+exp(-1*(_b[cut2:_cons]))) // intercept for y<2 in probability
	
display as result "MAIN EFFECTS ORDINAL MODEL PREDICTING CATEGORICAL DV"
display as result "INTERCEPTS ARE BACKWARDS (GIVE LOGIT OF LOWER CATEGORY)" 
meologit apply c.gpa3 c.parentgd c.private,
estat ic, n(400),
margins, at(c.gpa3=(-1(1)1) c.parentgd=(0(1)1) c.private=(0(1)1)) predict(xb) // logits
margins, at(c.gpa3=(-1(1)1) c.parentgd=(0(1)1) c.private=(0(1)1))             // probabilities	
	
display as result "MAIN EFFECTS ORDINAL MODEL PREDICTING CATEGORICAL DV"
display as result "INTERCEPTS ARE BACKWARDS (GIVES LOGIT OF LOWER CATEGORY)"
display as result "ODDS RATIOS INSTEAD OF LOGITS" 
meologit apply c.gpa3 c.parentgd c.private, or,
estat ic, n(400),
margins, at(c.gpa3=(-1(1)1) c.parentgd=(0(1)1) c.private=(0(1)1)) predict(xb) // logits
margins, at(c.gpa3=(-1(1)1) c.parentgd=(0(1)1) c.private=(0(1)1))             // probabilities	
	
* STATA does not have a mixed-effects version of a nominal model (except in GSEM)
* So we must return to a univariate version instead

display as result "EMPTY NOMINAL MODEL PREDICTING CATEGORICAL DV"
display as result "INTERCEPTS ARE NO LONGER BACKWARDS (GIVES LOGIT OF NON-BASE CATEGORY)" 
mlogit apply , baseoutcome(1), 
estat ic, n(400),
nlcom 1/(1+exp(-1*(_b[0No:_cons])))  // intercept for y=0 instead of 1 in probability
nlcom 1/(1+exp(-1*(_b[2Yes:_cons]))) // intercept for y=2 instead of 1 in probability
	
display as result "MAIN EFFECTS NOMINAL MODEL PREDICTING CATEGORICAL DV"
display as result "INTERCEPTS ARE NO LONGER BACKWARDS (GIVES LOGIT OF NON-BASE CATEGORY)" 
mlogit apply c.gpa3 c.parentgd c.private, baseoutcome(1), 
estat ic, n(400),
margins, at(c.gpa3=(-1(1)1) c.parentgd=(0(1)1) c.private=(0(1)1)) predict(xb) // logits
margins, at(c.gpa3=(-1(1)1) c.parentgd=(0(1)1) c.private=(0(1)1))             // probabilities	
	
* Close log	
log close STATA_Example10b
